# -*- coding: utf-8 -*-
import sleekxmpp

class SendMsgBot(sleekxmpp.ClientXMPP):
    """
    A basic SleekXMPP bot that will log in, send a message,
    and then log out.
    """

    def __init__(self, jid, password, recipient, message):
        sleekxmpp.ClientXMPP.__init__(self, jid, password)

        # The message we wish to send, and the JID that
        # will receive it.
        self.recipient = recipient
        self.msg = message

        # The session_start event will be triggered when
        # the bot establishes its connection with the server
        # and the XML streams are ready for use. We want to
        # listen for this event so that we we can initialize
        # our roster.
        self.add_event_handler("session_start", self.start)

    def start(self, event):
        """
        Process the session_start event.

        Typical actions for the session_start event are
        requesting the roster and broadcasting an initial
        presence stanza.

        Arguments:
            event -- An empty dictionary. The session_start
                     event does not provide any additional
                     data.
        """
        self.send_presence()
        self.get_roster()

        self.send_message(mto=self.recipient, mbody=self.msg, mtype='chat')

        # Using wait=True ensures that the send queue will be
        # emptied before ending the session.
        self.disconnect(wait=True)



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Author: Massimiliano Torromeo <massimiliano.torromeo@gmail.com>
# License: BSD

name = "xmppcat"
description = "CLI application that works like cat but sends its output through xmpp"
version = "0.1.1"
url = "http://github.com/mtorromeo/xmppcat"

import os
import sys


def main():
    import setproctitle
    import argparse
    import configparser
    import logging
    from .bot import SendMsgBot

    setproctitle.setproctitle(name)

    parser = argparse.ArgumentParser(prog=name, description=description)

    parser.add_argument('-V', '--version', action='version', version="%(prog)s " + version)
    parser.add_argument('-c', '--config', help='Use a different configuration file')
    parser.add_argument('-H', '--host', help='XMPP host (%(prog)s will try to auto detect it with DNS or JID parsing)')
    parser.add_argument('-P', '--port', help='XMPP port', type=int, default=5222)
    parser.add_argument('-u', '--user', help='XMPP username (JID)')
    parser.add_argument('-p', '--pass', dest='pwd', help='XMPP password')
    parser.add_argument('recipient', nargs=1, help='The XMPP jid to send the message to')
    parser.add_argument('file', nargs='?', help='The file to read. If not specified it will be read from STDIN')

    # Output verbosity options.
    default_loglevel = logging.WARNING
    group = parser.add_argument_group('output arguments')
    group.add_argument('-q', '--quiet', help='Suppress any non-error output', action='store_const', dest='loglevel', const=logging.ERROR, default=default_loglevel)
    group.add_argument('-d', '--debug', help='Enable debugging output', action='store_const', dest='loglevel', const=logging.DEBUG, default=default_loglevel)
    group.add_argument('-v', '--verbose', help='Show additional connection informations', action='store_const', dest='loglevel', const=logging.INFO, default=default_loglevel)

    args = parser.parse_args()

    config = configparser.SafeConfigParser(defaults=dict(status_url="http://127.0.0.1/server-status"))
    try:
        if args.config:
            config.read(args.config)
        else:
            config.read(["/etc/{}.conf".format(name), os.path.expanduser("~/.{}.conf".format(name))])
    except configparser.Error as e:
        sys.exit(e.message)

    config = config['DEFAULT']

    recipient = args.recipient[0]
    if args.file:
        with open(args.file, 'r') as f:
            message = f.read()
    else:
        message = sys.stdin.read()
    pwd = args.pwd if args.pwd else config.get('pass', '')
    user = args.user if args.user else config.get('user', '')

    # Logging
    logging.basicConfig(level=args.loglevel, format='%(levelname)-8s %(message)s')

    server_options = list()
    if args.host:
        server_options.append((args.host, args.port))

    xmpp = SendMsgBot(user, pwd, recipient, message)
    if xmpp.connect(*server_options):
        xmpp.process(block=True)
    else:
        sys.exit("Unable to connect.")

if __name__ == '__main__':
    main()



#!/usr/bin/env python
# -*- coding:utf-8 -*-

import sys
import os
from xmppcat import __main__ as application

try:
    from setuptools import setup
except ImportError:
    print( 'The installation require distribute, please install it' )

here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()

requires = ["setproctitle", "sleekxmpp"]

setup(
    name = application.name,
    scripts = ['bin/xmppcat'],
    packages = ['xmppcat'],
    install_requires = requires,
    version = application.version,
    description = application.description,
    long_description = README,
    author = "Massimiliano Torromeo",
    author_email = "massimiliano.torromeo@gmail.com",
    url = application.url,
    download_url = "{}/tarball/v{}".format(application.url, application.version),
    classifiers = [
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Development Status :: 4 - Beta",
        "License :: OSI Approved :: BSD License",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: POSIX :: Linux",
        "Operating System :: POSIX :: BSD",
        "Natural Language :: English",
    ],
    license = "BSD License"
)